import datetime

def compare_my_age():
    my_birth_date = datetime.datetime(2000, 8, 18)
    present_date = datetime.datetime.now()

    duration = (present_date - my_birth_date)
    duration_in_s = duration.total_seconds()
    my_age = divmod(duration_in_s, 31536000)[0]

    
    your_age = int(input('Enter Your Age\n'))

    statement = 'You are a little baby' if my_age >= your_age else 'You are older'
    print(statement)


import os.path
from setuptools import setup


# The directory containing this file
HERE = os.path.abspath(os.path.dirname(__file__))

# The text of the README file
with open(os.path.join(HERE, "README.md")) as fid:
    README = fid.read()

setup(
    name="agecal_mick",
    version="2.0.1",
    description="Compare age with mickzaa return older or younger",
    long_description=README,
    long_description_content_type="text/markdown",
    author="Mickzaa",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 3",
    ],
    packages=["agecal"],
    include_package_data=True,
    install_requires=[],
    entry_points={"console_scripts": ["realpython=agecal.__main__:main"]},
)